==> CGAL-4.10-doc_html.tar.xz: doc_html/Optimal_transportation_reconstruction_2/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
".html":[5,0],
"Optimal_transportation_reconstruction_2_2otr2_indexed_output_example_8cpp-example.html":[6,0],
"Optimal_transportation_reconstruction_2_2otr2_list_output_example_8cpp-example.html":[6,1],
"Optimal_transportation_reconstruction_2_2otr2_mass_example_8cpp-example.html":[6,2],
"Optimal_transportation_reconstruction_2_2otr2_simplest_example_8cpp-example.html":[6,3],
"annotated.html":[5],
"citelist.html":[4],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html":[1,0,1,0],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a124dba5f9ea1fd561df35e499936679d":[1,0,1,0,11],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a271099d8a696b99c74731634717ea6cf":[1,0,1,0,5],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a28260d575a16a1e351381016692ee14f":[1,0,1,0,13],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a4da6cbf9c758cd7e04cd281f8bbd4960":[1,0,1,0,8],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a5a6558881ec7202b16384318605bb3c3":[1,0,1,0,0],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a6d945a9ddf0faa394e4d15e2e3e7b831":[1,0,1,0,3],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a8cbbcfc431de3be57cdc3cf986521dc1":[1,0,1,0,1],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a9d13bdd2e76d4503e049728ee006e357":[1,0,1,0,10],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#aab57b59f1f4becd99240a6e368d23068":[1,0,1,0,4],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ac7070d263cfc0776e18c6e2ac1a5e651":[1,0,1,0,2],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad491547e673dcbde076d68018e56ea8f":[1,0,1,0,12],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#aec29a3302616e3b9975d4f3290af95e0":[1,0,1,0,6],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#af2f0f6e6b52b27e5f558b14f3f670c71":[1,0,1,0,7],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#afd9b7e1ac33076cce2a7027c8857e511":[1,0,1,0,9],
"classOptimalTransportationReconstructionTraits__2.html":[1,0,0,0],
"classOptimalTransportationReconstructionTraits__2.html#a15d7f934c9398ad37c0b408705055160":[1,0,0,0,15],
"classOptimalTransportationReconstructionTraits__2.html#a2575c3b8720e51ae709b2724fd085caf":[1,0,0,0,18],
"classOptimalTransportationReconstructionTraits__2.html#a26a5b01be679c2b4312e39c5adcc1f97":[1,0,0,0,9],
"classOptimalTransportationReconstructionTraits__2.html#a33d28f1644b373e2a53c90d0e4314f90":[1,0,0,0,3],
"classOptimalTransportationReconstructionTraits__2.html#a369f46e5477d44b7333fcc3de8cc0ecc":[1,0,0,0,4],
"classOptimalTransportationReconstructionTraits__2.html#a36db4168f8ccb6fc6af753757edf0cbc":[1,0,0,0,5],
"classOptimalTransportationReconstructionTraits__2.html#a448d96f6fc1cff5166e68f1ebfa2c07c":[1,0,0,0,13],
"classOptimalTransportationReconstructionTraits__2.html#a44fd79fe80e6b90644a1677cc86ce09d":[1,0,0,0,12],
"classOptimalTransportationReconstructionTraits__2.html#a52671ff4e58f18ae066a1c8458c3ac1a":[1,0,0,0,8],
"classOptimalTransportationReconstructionTraits__2.html#a65d0f1d61a564255172c7ee8fddbffcf":[1,0,0,0,6],
"classOptimalTransportationReconstructionTraits__2.html#a65ec9c82d9c1d66082ee37625c974837":[1,0,0,0,26],
"classOptimalTransportationReconstructionTraits__2.html#a67c53bdefbf3b491867d7e7323ccbe63":[1,0,0,0,27],
"classOptimalTransportationReconstructionTraits__2.html#a6b2e7b88d2a9fb827de8118029c9e498":[1,0,0,0,23],
"classOptimalTransportationReconstructionTraits__2.html#a703727c44d332eab364fcfb157381265":[1,0,0,0,22],
"classOptimalTransportationReconstructionTraits__2.html#a795e996bd0add2fa52456803916412d2":[1,0,0,0,16],
"classOptimalTransportationReconstructionTraits__2.html#a9986f38674289af3626a5884fd7bdf2c":[1,0,0,0,7],
"classOptimalTransportationReconstructionTraits__2.html#aa1bb35021d02915ed1d933b35c6d7071":[1,0,0,0,10],
"classOptimalTransportationReconstructionTraits__2.html#aa4c87e6d3c9fe46275a44a1df2604dc7":[1,0,0,0,2],
"classOptimalTransportationReconstructionTraits__2.html#aba8168faaa016cf0a580307b46164b2a":[1,0,0,0,14],
"classOptimalTransportationReconstructionTraits__2.html#acd8af60b801962386d8a6644aa93e52a":[1,0,0,0,1],
"classOptimalTransportationReconstructionTraits__2.html#ad384e0e0ba4e48edfbfaf7a3e8756b69":[1,0,0,0,19],
"classOptimalTransportationReconstructionTraits__2.html#ad5b4dfb7fd23161d4c58312e2d104c1a":[1,0,0,0,11],
"classOptimalTransportationReconstructionTraits__2.html#adbcb71130ca4920056fff2d665f105c4":[1,0,0,0,17],
"classOptimalTransportationReconstructionTraits__2.html#ae579b145566f6f318388f3909dae80de":[1,0,0,0,21],
"classOptimalTransportationReconstructionTraits__2.html#af14e98e0795d436cee9d5b9bfe2af81a":[1,0,0,0,20],
"classOptimalTransportationReconstructionTraits__2.html#af43c99a454e3a87f459eec3033b284fc":[1,0,0,0,25],
"classOptimalTransportationReconstructionTraits__2.html#af43c99a454e3a87f459eec3033b284fc":[1,0,0,0,24],
"classOptimalTransportationReconstructionTraits__2.html#afcb873209108dc04e537889027b443e0":[1,0,0,0,0],
"examples.html":[6],
"group__PkgOptimalTransportationReconstruction2.html":[1,0],
"group__PkgOptimalTransportationReconstruction2Classes.html":[1,0,1],
"group__PkgOptimalTransportationReconstruction2Concepts.html":[1,0,0],
"hasModels.html":[3],
"index.html":[0],
"index.html":[],
"index.html#Optimal_transportation_reconstruction_2API":[0,1],
"index.html#Optimal_transportation_reconstruction_2Density":[0,4],
"index.html#Optimal_transportation_reconstruction_2Flip":[0,2,0],
"index.html#Optimal_transportation_reconstruction_2Global_relocation":[0,1,1],
"index.html#Optimal_transportation_reconstruction_2History":[0,8],
"index.html#Optimal_transportation_reconstruction_2HowDoesItWork":[0,7],
"index.html#Optimal_transportation_reconstruction_2Introduction":[0,0],
"index.html#Optimal_transportation_reconstruction_2Local_relocation":[0,2,3],
"index.html#Optimal_transportation_reconstruction_2Mass_example":[0,0,2],
"index.html#Optimal_transportation_reconstruction_2Mixed":[0,5],
"index.html#Optimal_transportation_reconstruction_2Output_example":[0,0,1],
"index.html#Optimal_transportation_reconstruction_2Parameters":[0,2],
"index.html#Optimal_transportation_reconstruction_2Random":[0,2,2],
"index.html#Optimal_transportation_reconstruction_2Reconstruction":[0,7,1],
"index.html#Optimal_transportation_reconstruction_2Relevance":[0,2,1],
"index.html#Optimal_transportation_reconstruction_2Robustness":[0,3],
"index.html#Optimal_transportation_reconstruction_2Sample":[0,1,0],
"index.html#Optimal_transportation_reconstruction_2Simplest_example":[0,0,0],
"index.html#Optimal_transportation_reconstruction_2Variable_mass":[0,6],
"index.html#Optimal_transportation_reconstruction_2Verbose":[0,2,4],
"index.html#Optimal_transportation_reconstruction_2Wasserstein":[0,7,0],
"modules.html":[1],
"pages.html":[],
"refines.html":[2]
};

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Optimal_transportation_reconstruction_2/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
".html":[5,0],
"Optimal_transportation_reconstruction_2_2otr2_indexed_output_example_8cpp-example.html":[6,0],
"Optimal_transportation_reconstruction_2_2otr2_list_output_example_8cpp-example.html":[6,1],
"Optimal_transportation_reconstruction_2_2otr2_mass_example_8cpp-example.html":[6,2],
"Optimal_transportation_reconstruction_2_2otr2_simplest_example_8cpp-example.html":[6,3],
"Optimal_transportation_reconstruction_2_2otr2_simplest_example_with_tolerance_8cpp-example.html":[6,4],
"annotated.html":[5],
"citelist.html":[4],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html":[1,0,1,0],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a0ef3805808558ea082ef24298c7c9286":[1,0,1,0,23],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a124dba5f9ea1fd561df35e499936679d":[1,0,1,0,12],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a12a9e844d7231128492136405c421d65":[1,0,1,0,4],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a1d5fd670da81f8ff25e3e6ba5c20b1c0":[1,0,1,0,24],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a28260d575a16a1e351381016692ee14f":[1,0,1,0,14],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a2bfada5b599576d86ca83ba4aa2f3eda":[1,0,1,0,19],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a3c28d325eb5f428f43e706d073d2b093":[1,0,1,0,15],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a4af8bc9ee0f74fa258d0891b2add6fc1":[1,0,1,0,16],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a4da6cbf9c758cd7e04cd281f8bbd4960":[1,0,1,0,9],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a58f887a13faf03c97bcbd37178d4120c":[1,0,1,0,17],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a5a6558881ec7202b16384318605bb3c3":[1,0,1,0,0],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a5e87eae7abf14365e35684d00ef18921":[1,0,1,0,22],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a6d945a9ddf0faa394e4d15e2e3e7b831":[1,0,1,0,3],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a6e911803fab5bc37df386173b5b4e91f":[1,0,1,0,20],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a737669da7d8bcd0e6bdd053f6067b155":[1,0,1,0,27],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a8018135d6110cf7e4d9ae4c72f8ae905":[1,0,1,0,18],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a8cbbcfc431de3be57cdc3cf986521dc1":[1,0,1,0,1],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#a9d13bdd2e76d4503e049728ee006e357":[1,0,1,0,11],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#aa7a32398e56863507255a93294664bcf":[1,0,1,0,7],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ac7070d263cfc0776e18c6e2ac1a5e651":[1,0,1,0,2],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ac8219d34e53daf0c96a27b1d308c9f3b":[1,0,1,0,26],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad491547e673dcbde076d68018e56ea8f":[1,0,1,0,13],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad94fc673df480c8b2076ae542fdd0e04":[1,0,1,0,5],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ada2cdd4244c0005d0527acdb68cb02cb":[1,0,1,0,8],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#ae23986053aebb5d4655aea4fd9d58dab":[1,0,1,0,25],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#aec29a3302616e3b9975d4f3290af95e0":[1,0,1,0,6],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#af0b7d350312bc77bd3d7a20223891834":[1,0,1,0,21],
"classCGAL_1_1Optimal__transportation__reconstruction__2.html#afd9b7e1ac33076cce2a7027c8857e511":[1,0,1,0,10],
"classOptimalTransportationReconstructionTraits__2.html":[1,0,0,0],
"classOptimalTransportationReconstructionTraits__2.html#a15d7f934c9398ad37c0b408705055160":[1,0,0,0,15],
"classOptimalTransportationReconstructionTraits__2.html#a2575c3b8720e51ae709b2724fd085caf":[1,0,0,0,18],
"classOptimalTransportationReconstructionTraits__2.html#a26a5b01be679c2b4312e39c5adcc1f97":[1,0,0,0,9],
"classOptimalTransportationReconstructionTraits__2.html#a33d28f1644b373e2a53c90d0e4314f90":[1,0,0,0,3],
"classOptimalTransportationReconstructionTraits__2.html#a369f46e5477d44b7333fcc3de8cc0ecc":[1,0,0,0,4],
"classOptimalTransportationReconstructionTraits__2.html#a36db4168f8ccb6fc6af753757edf0cbc":[1,0,0,0,5],
"classOptimalTransportationReconstructionTraits__2.html#a448d96f6fc1cff5166e68f1ebfa2c07c":[1,0,0,0,13],
"classOptimalTransportationReconstructionTraits__2.html#a44fd79fe80e6b90644a1677cc86ce09d":[1,0,0,0,12],
"classOptimalTransportationReconstructionTraits__2.html#a52671ff4e58f18ae066a1c8458c3ac1a":[1,0,0,0,8],
"classOptimalTransportationReconstructionTraits__2.html#a65d0f1d61a564255172c7ee8fddbffcf":[1,0,0,0,6],
"classOptimalTransportationReconstructionTraits__2.html#a65ec9c82d9c1d66082ee37625c974837":[1,0,0,0,25],
"classOptimalTransportationReconstructionTraits__2.html#a67c53bdefbf3b491867d7e7323ccbe63":[1,0,0,0,26],
"classOptimalTransportationReconstructionTraits__2.html#a6b2e7b88d2a9fb827de8118029c9e498":[1,0,0,0,23],
"classOptimalTransportationReconstructionTraits__2.html#a703727c44d332eab364fcfb157381265":[1,0,0,0,22],
"classOptimalTransportationReconstructionTraits__2.html#a795e996bd0add2fa52456803916412d2":[1,0,0,0,16],
"classOptimalTransportationReconstructionTraits__2.html#a9986f38674289af3626a5884fd7bdf2c":[1,0,0,0,7],
"classOptimalTransportationReconstructionTraits__2.html#aa1bb35021d02915ed1d933b35c6d7071":[1,0,0,0,10],
"classOptimalTransportationReconstructionTraits__2.html#aa4c87e6d3c9fe46275a44a1df2604dc7":[1,0,0,0,2],
"classOptimalTransportationReconstructionTraits__2.html#aba8168faaa016cf0a580307b46164b2a":[1,0,0,0,14],
"classOptimalTransportationReconstructionTraits__2.html#acd8af60b801962386d8a6644aa93e52a":[1,0,0,0,1],
"classOptimalTransportationReconstructionTraits__2.html#ad384e0e0ba4e48edfbfaf7a3e8756b69":[1,0,0,0,19],
"classOptimalTransportationReconstructionTraits__2.html#ad5b4dfb7fd23161d4c58312e2d104c1a":[1,0,0,0,11],
"classOptimalTransportationReconstructionTraits__2.html#adbcb71130ca4920056fff2d665f105c4":[1,0,0,0,17],
"classOptimalTransportationReconstructionTraits__2.html#ae579b145566f6f318388f3909dae80de":[1,0,0,0,21],
"classOptimalTransportationReconstructionTraits__2.html#af14e98e0795d436cee9d5b9bfe2af81a":[1,0,0,0,20],
"classOptimalTransportationReconstructionTraits__2.html#af43c99a454e3a87f459eec3033b284fc":[1,0,0,0,24],
"classOptimalTransportationReconstructionTraits__2.html#afcb873209108dc04e537889027b443e0":[1,0,0,0,0],
"examples.html":[6],
"group__PkgOptimalTransportationReconstruction2Classes.html":[1,0,1],
"group__PkgOptimalTransportationReconstruction2Concepts.html":[1,0,0],
"group__PkgOptimalTransportationReconstruction2Ref.html":[1,0],
"hasModels.html":[3],
"index.html":[0],
"index.html":[],
"index.html#Optimal_transportation_reconstruction_2API":[0,1],
"index.html#Optimal_transportation_reconstruction_2Density":[0,4],
"index.html#Optimal_transportation_reconstruction_2Flip":[0,2,0],
"index.html#Optimal_transportation_reconstruction_2Global_relocation":[0,1,1],
"index.html#Optimal_transportation_reconstruction_2History":[0,8],
"index.html#Optimal_transportation_reconstruction_2HowDoesItWork":[0,7],
"index.html#Optimal_transportation_reconstruction_2Introduction":[0,0],
"index.html#Optimal_transportation_reconstruction_2Local_relocation":[0,2,3],
"index.html#Optimal_transportation_reconstruction_2Mass_example":[0,0,2],
"index.html#Optimal_transportation_reconstruction_2Mixed":[0,5],
"index.html#Optimal_transportation_reconstruction_2Output_example":[0,0,1],
"index.html#Optimal_transportation_reconstruction_2Parameters":[0,2],
"index.html#Optimal_transportation_reconstruction_2Random":[0,2,2],
"index.html#Optimal_transportation_reconstruction_2Reconstruction":[0,7,1],
"index.html#Optimal_transportation_reconstruction_2Relevance":[0,2,1],
"index.html#Optimal_transportation_reconstruction_2Robustness":[0,3],
"index.html#Optimal_transportation_reconstruction_2Sample":[0,1,0],
"index.html#Optimal_transportation_reconstruction_2Simplest_example":[0,0,0],
"index.html#Optimal_transportation_reconstruction_2Variable_mass":[0,6],
"index.html#Optimal_transportation_reconstruction_2Verbose":[0,2,4],
"index.html#Optimal_transportation_reconstruction_2Wasserstein":[0,7,0],
"modules.html":[1],
"pages.html":[],
"refines.html":[2]
};
